Crate wick_wascap

WasCap implementation for Wick components

Structs

Claims
Represents a set of RFC 7519 compliant JSON Web Token claims.
Token
A structure containing a JWT and its associated decoded claims
WickComponent
The metadata that corresponds to a wick component module.

Enums

ClaimsOptions
A common struct to group related options together.
Error
Wick WasCap’s error type.

Functions

extract_claims
Extract the claims embedded in a WebAssembly module.
sign_buffer_with_claims
Sign WebAssembly bytes with the passed claims.
validate_token
Validates a signed JWT. This will check the signature, expiration time, and not-valid-before time