#[non_exhaustive]pub struct WickComponent {
pub module_hash: String,
pub tags: Option<Vec<String>>,
pub interface: ComponentSignature,
pub ver: Option<String>,
}Expand description
The metadata that corresponds to a wick component module.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.module_hash: StringA hash of the module’s bytes as they exist without the embedded signature. This is stored so wascap. can determine if a WebAssembly module’s bytecode has been altered after it was signed.
List of arbitrary string tags associated with the claims.
interface: ComponentSignatureThe schema for the module
ver: Option<String>Indicates a human-friendly version string.